@@ -95,6 +95,8 @@ export function send(component, callback) {
       component.data = responseJson.data || {};
       component.errors = responseJson.errors || {};
       component.return = responseJson.return || {};
+
+      const parent = responseJson.parent || {};
       const rerenderedComponent = responseJson.dom;
 
       // Handle poll
@@ -116,10 +118,31 @@ export function send(component, callback) {
         component.startPolling();
       }
 
+      // Refresh the parent component if there is one
+      if (hasValue(parent) && hasValue(parent.id) && hasValue(parent.dom)) {
+        const parentComponent = component.getParentComponent(parent.id);
+
+        if (parentComponent && parentComponent.id === parent.id) {
+          // TODO: Handle errors?
+          parentComponent.data = parent.data || {};
+
+          component.morphdom(
+            parentComponent.root,
+            parent.dom,
+            MORPHDOM_OPTIONS
+          );
+          parentComponent.refreshChecksum();
+
+          // parentComponent.getChildrenComponents().forEach((child) => {
+          //   child.refreshEventListeners();
+          // });
+        }
+      }
+
       component.morphdom(component.root, rerenderedComponent, MORPHDOM_OPTIONS);
 
-      // Refresh the checksum based on the new data
-      component.refreshChecksum();
+      // Re-init to refresh the root and checksum based on the new data
+      component.init();
 
       // Reset all event listeners
       component.refreshEventListeners();
